@@ -1,8 +1,9 @@
 <?php
 /**
- * An PEAR-Net_Imap based Kolab storage driver.
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
- * PHP version 5
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category Kolab
  * @package  Kolab_Storage
@@ -14,11 +15,6 @@
 /**
  * An PEAR-Net_Imap based Kolab storage driver.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.horde.org/licenses/lgpl21.
- *
  * @category Kolab
  * @package  Kolab_Storage
  * @author   Gunnar Wrobel <wrobel@pardus.de>
@@ -489,13 +485,13 @@ extends Horde_Kolab_Storage_Driver_Base
     {
         $ob = new Horde_Mime_Part();
 
-        $ob->setType(strtolower($data->type) . '/' . strtolower($data->subType));
+        $ob->setType(Horde_String::lower($data->type) . '/' . Horde_String::lower($data->subType));
 
         // Optional for multipart-parts, required for all others
         if (isset($data->parameters)) {
             $params = array();
             foreach ($data->parameters as $key => $value) {
-                $params[strtolower($key)] = $value;
+                $params[Horde_String::lower($key)] = $value;
             }
 
             $params = Horde_Mime::decodeParam('content-type', $params);
@@ -510,7 +506,7 @@ extends Horde_Kolab_Storage_Driver_Base
             if (isset($data->dparameters)) {
                 $dparams = array();
                 foreach ($data->dparameters as $key => $value) {
-                    $dparams[strtolower($key)] = $value;
+                    $dparams[Horde_String::lower($key)] = $value;
                 }
 
                 $dparams = Horde_Mime::decodeParam('content-disposition', $dparams);
@@ -531,7 +527,7 @@ extends Horde_Kolab_Storage_Driver_Base
                 $ob->setContentId($data->partID);
             }
 
-            $ob->setTransferEncoding(strtolower($data->encoding));
+            $ob->setTransferEncoding(Horde_String::lower($data->encoding));
             $ob->setBytes($data->bytes);
 
             if ($ob->getType() == 'message/rfc822') {
