@@ -1,8 +1,9 @@
 <?php
 /**
- * A Roundcube Imap based Kolab storage driver.
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
- * PHP version 5
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category Kolab
  * @package  Kolab_Storage
@@ -14,11 +15,6 @@
 /**
  * A Roundcube Imap based Kolab storage driver.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.horde.org/licenses/lgpl21.
- *
  * @category Kolab
  * @package  Kolab_Storage
  * @author   Gunnar Wrobel <wrobel@pardus.de>
@@ -875,7 +871,7 @@ extends Horde_Kolab_Storage_Driver_Base
 
         if (is_array($data)) {
             for ($i = 0, $cnt = count($data); $i < $cnt; ++$i) {
-                $params[strtolower($data[$i])] = $data[++$i];
+                $params[Horde_String::lower($data[$i])] = $data[++$i];
             }
         }
 
