@@ -16,7 +16,7 @@
  * This class converts PEAR errors into exceptions for the Kolab_Storage
  * package.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -39,7 +39,7 @@ extends Horde_Exception_Pear
      *
      * @throws Horde_Exception_Pear In case the result was a PEAR_Error.
      */
-    static public function catchError($result)
+    public static function catchError($result)
     {
         self::$_class = __CLASS__;
         return parent::catchError($result);
