@@ -15,7 +15,7 @@
 /**
  * Tests the creation of new Kolab mime messages.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -32,11 +32,6 @@ extends PHPUnit_Framework_TestCase
 {
     public function testStore()
     {
-        if (version_compare(PHP_VERSION, '5.5.0', '>=') &&
-            version_compare(PHP_VERSION, '5.5.3', '<=')) {
-            $this->markTestSkipped('PHP version with broken quoted-printable-encode');
-        }
-
         setlocale(LC_MESSAGES, 'C');
         $factory = new Horde_Kolab_Format_Factory();
         $writer = new Horde_Kolab_Storage_Object_Writer_Format(
@@ -96,17 +91,16 @@ Content-Disposition: attachment; filename="Kolab Groupware Data"
 This message is in MIME format.
 
 --=_
-Content-Type: text/plain; name="Kolab Groupware Information"; charset=utf-8
+Content-Type: text/plain; charset=utf-8; name="Kolab Groupware Information"
 Content-Disposition: inline; filename="Kolab Groupware Information"
 
 This is a Kolab Groupware object. To view this object you will need an email client that understands the Kolab Groupware format. For a list of such email clients please visit http://www.kolab.org/content/kolab-clients
 --=_
 Content-Type: application/x-vnd.kolab.note; name=kolab.xml
 Content-Disposition: inline; x-kolab-type=xml; filename=kolab.xml
-Content-Transfer-Encoding: quoted-printable
 
-<?xml version=3D"1.0" encoding=3D"UTF-8"?>
-<note version=3D"1.0">
+<?xml version="1.0" encoding="UTF-8"?>
+<note version="1.0">
   <uid>ABC1234</uid>
   <body></body>
   <categories></categories>
