@@ -15,7 +15,7 @@
 /**
  * Tests the Kolab mime message parser.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -71,9 +71,8 @@ extends PHPUnit_Framework_TestCase
         $data = $this->getMock('Horde_Kolab_Storage_Object_Writer');
         $object = new Horde_Kolab_Storage_Object();
         $headers = $this->getMock('Horde_Mime_Headers');
-        $headers->expects($this->once())
-            ->method('getValue')
-            ->with('X-Kolab-Type')
+        $headers->method('__call')
+            ->with('getValue', array('X-Kolab-Type'))
             ->will($this->returnValue('application/x-vnd.kolab.note'));
         $this->folder->expects($this->once())
             ->method('getType')
@@ -100,9 +99,8 @@ extends PHPUnit_Framework_TestCase
         $data = $this->getMock('Horde_Kolab_Storage_Object_Writer');
         $object = new Horde_Kolab_Storage_Object();
         $headers = $this->getMock('Horde_Mime_Headers');
-        $headers->expects($this->once())
-            ->method('getValue')
-            ->with('X-Kolab-Type')
+        $headers->method('__call')
+            ->with('getValue', array('X-Kolab-Type'))
             ->will($this->returnValue('application/x-vnd.kolab.note'));
         $this->folder->expects($this->once())
             ->method('getType')
@@ -137,9 +135,8 @@ extends PHPUnit_Framework_TestCase
         $data = $this->getMock('Horde_Kolab_Storage_Object_Writer');
         $object = new Horde_Kolab_Storage_Object();
         $headers = $this->getMock('Horde_Mime_Headers');
-        $headers->expects($this->once())
-            ->method('getValue')
-            ->with('X-Kolab-Type')
+        $headers->method('__call')
+            ->with('getValue', array('X-Kolab-Type'))
             ->will($this->returnValue('application/x-vnd.kolab.note'));
         $this->folder->expects($this->once())
             ->method('getType')
@@ -326,9 +323,8 @@ extends PHPUnit_Framework_TestCase
         $data = $this->getMock('Horde_Kolab_Storage_Object_Writer');
         $object = new Horde_Kolab_Storage_Object();
         $headers = $this->getMock('Horde_Mime_Headers');
-        $headers->expects($this->once())
-            ->method('getValue')
-            ->with('X-Kolab-Type')
+        $headers->method('__call')
+            ->with('getValue', array('X-Kolab-Type'))
             ->will($this->returnValue('application/x-vnd.kolab.note'));
         $this->folder->expects($this->once())
             ->method('getType')
@@ -577,7 +573,7 @@ extends PHPUnit_Framework_TestCase
 
         $this->assertContains('Content-Disposition: attachment; filename="Kolab Groupware Data"', $driver->messages['INBOX'][0]);
         $this->assertContains('Content-Type: multipart/mixed;', $driver->messages['INBOX'][0]);
-        $this->assertContains('Content-Type: text/plain; name="Kolab Groupware Information"; charset=utf-8', $driver->messages['INBOX'][0]);
+        $this->assertContains('Content-Type: text/plain; charset=utf-8; name="Kolab Groupware Information"', $driver->messages['INBOX'][0]);
         $this->assertContains('Content-Disposition: inline; filename="Kolab Groupware Information"', $driver->messages['INBOX'][0]);
         $this->assertContains(
             "This is a Kolab Groupware object. To view this object you will need an email client that understands the Kolab Groupware format. For a list of such email clients please visit http://www.kolab.org/content/kolab-clients",
